# coding: utf-8

from django.db import models
from django.utils.translation import ugettext_lazy as _
from cms.models.pagemodel import Page

from jmb.core.db.models import DateModel, UserModel


class Category(DateModel, UserModel):
    name = models.CharField(
        unique=True,
        max_length=100,
        verbose_name=_("Name"),
    )

    class Meta:
        verbose_name = _("Category")
        verbose_name_plural = _("Categories")
        ordering = ('name',)

    def __unicode__(self):
        return u"{}".format(self.name)


class PageCategory(models.Model):
    page = models.ForeignKey(
        Page,
        related_name='categories',
        verbose_name=_("Page"),
        editable=False,
    )
    category = models.ForeignKey(
        Category,
        related_name='pages',
        verbose_name='Category',
    )

    class Meta:
        verbose_name = _("Page category")
        verbose_name_plural = _("Page categories")

    def __unicode__(self):
        return u"{}: {}".format(self.page.id, self.category.name)


